@@ -1,4 +1,4 @@
-/*  Moe - My Own Editor
+/*  GNU Moe - My Own Editor
     Copyright (C) 2005 Antonio Diaz Diaz.
 
     This program is free software; you can redistribute it and/or modify
@@ -174,7 +174,7 @@ Buffer::Buffer( const Options & opts, const std::string * namep ) throw( Buffer:
 
 
 bool Buffer::save( const std::string * namep, bool set_name, bool append,
-                   Point p1, Point p2 ) throw( Buffer::Error )
+                   Point p1, Point p2 ) const throw( Buffer::Error )
   {
   int mode = 0;
   struct stat st;
@@ -493,7 +493,7 @@ Bufhandle_vector::~Bufhandle_vector() throw()
   RC::options().backup = false;
   FILE *f = std::fopen( dead_name.c_str(), "a" );
   time_t dummy = time( 0 );
-  std::fprintf( f, "\n*** Modified files in MOE when it aborted on %s", ctime( &dummy ) );
+  std::fprintf( f, "\n*** Modified files in Moe when it aborted on %s", ctime( &dummy ) );
   std::fflush( f );
   for( i = 0; i < handles(); ++i )
     if( data[i].buffer().modified() )
@@ -506,6 +506,23 @@ Bufhandle_vector::~Bufhandle_vector() throw()
   }
 
 
+bool Bufhandle_vector::save_all_named() const throw()
+  {
+  bool done = true;
+
+  for( int i = 0; i < handles(); ++i )
+    {
+    const Buffer & buffer = data[i].buffer();
+    if( buffer.modified() && buffer.name().size() )
+      {
+      try { if( !buffer.save() ) done = false; }
+      catch( Buffer::Error ) { done = false; }
+      }
+    }
+  return done;
+  }
+
+
 int Bufhandle_vector::handles( const Buffer & buffer ) const throw()
   {
   int c = 0;
