@@ -1,4 +1,4 @@
-/*  Moe - My Own Editor
+/*  GNU Moe - My Own Editor
     Copyright (C) 2005 Antonio Diaz Diaz.
 
     This program is free software; you can redistribute it and/or modify
@@ -122,8 +122,9 @@ public:
 
 class Buffer : public Basic_buffer
   {
-  bool crlf, _modified, saved;
-  std::string _name;
+  bool crlf;
+  mutable bool _modified, saved;
+  mutable std::string _name;
 
   struct Change_history
     {
@@ -151,16 +152,16 @@ class Buffer : public Basic_buffer
 
     struct Record
       {
-      bool modified;	// Status of modified flag before this record
+      mutable bool modified;	// Status of modified flag before this record
       std::vector< Atom > atom_vector;
 
       Record( const bool m ) throw() : modified( m ) {}
       void add_atom( const Atom & a ) throw() { atom_vector.push_back( a ); }
       };
 
-    int index;		// Index of record to be undone
-    bool appendable;	// True if last record added is appendable
-    bool force_append;
+    int index;			// Index of record to be undone
+    mutable bool appendable;	// True if last record added is appendable
+    mutable bool force_append;
     std::vector< Record > record_vector;
 
     Change_history() throw()
@@ -203,7 +204,7 @@ public:
 
   Buffer( const Options & opts, const std::string * namep = 0 ) throw( Buffer::Error );
   bool save( const std::string * namep = 0, bool set_name = true, bool append = false,
-             Point p1 = Point(), Point p2 = Point() ) throw( Buffer::Error );
+             Point p1 = Point(), Point p2 = Point() ) const throw( Buffer::Error );
 
   const std::string & character_info( const Point & p ) const throw();
   bool modified() const throw() { return _modified; }
@@ -223,8 +224,8 @@ public:
 
   bool undo( Point & p ) throw();
   bool redo( Point & p ) throw();
-  void force_append() throw() { change_history.force_append = true; }
-  void reset_appendable() throw() { change_history.appendable = false; }
+  void force_append() const throw() { change_history.force_append = true; }
+  void reset_appendable() const throw() { change_history.appendable = false; }
   };
 
 
@@ -257,6 +258,7 @@ class Bufhandle_vector
 public:
   Bufhandle_vector() throw() : _first( 0 ) {}
   ~Bufhandle_vector() throw();
+  bool save_all_named() const throw();
 
   Buffer_handle & operator[]( int i ) throw()
     { return data[( _first + i ) % handles()]; }
