@@ -1,4 +1,4 @@
-/*  Moe - My Own Editor
+/*  GNU Moe - My Own Editor
     Copyright (C) 2005 Antonio Diaz Diaz.
 
     This program is free software; you can redistribute it and/or modify
@@ -23,12 +23,14 @@
 */
 
 //#include <clocale>
+#include <cctype>
 #include <csignal>
 #include <cstdio>
 #include <cstdlib>
 #include <ctime>
 #include <string>
 #include <vector>
+#include <unistd.h>
 
 #include "buffer.h"
 #include "rc.h"
@@ -37,13 +39,13 @@
 
 namespace {
 
-// Date of this version: 2005-09-01
+// Date of this version: 2005-09-16
 
 const char * invocation_name = 0;
 const char * const Program_name     = "GNU Moe";
 const char * const program_name     = "moe";
 const char * const config_file_name = "moerc";
-const char * const program_version  = "0.3";
+const char * const program_version  = "0.4";
 const char * const program_year     = "2005";
 
 
