@@ -1,4 +1,4 @@
-/*  Moe - My Own Editor
+/*  GNU Moe - My Own Editor
     Copyright (C) 2005 Antonio Diaz Diaz.
 
     This program is free software; you can redistribute it and/or modify
@@ -187,6 +187,7 @@ void control_q_loop( int key, int & retval ) throw()
   key = ISO_8859::decontrolize( key );
   switch( key )
     {
+    case KEY_F(2): window_vector.save_all_named(); break;
     case 'C': if( window_vector.close_and_exit( true ) == 0 ) retval = 0; break;
     case 'X': if( window_vector.close_and_exit( false ) == 0 ) retval = 0; break;
     }
@@ -287,7 +288,8 @@ void Screen::clock_handler( const int sig ) throw()	// updates the clock
 // Returns the size of the result string, 0 if none, -1 if aborted.
 //
 int Screen::get_string( const std::string & prompt,
-                        std::vector< std::string > & history, const bool usetab ) throw()
+                        std::vector< std::string > & history,
+                        const bool allow_copy, const bool usetab ) throw()
   {
   const int line = _height - 1, lines = 1;
   save_lines_and_cursor( line, lines );
@@ -323,6 +325,14 @@ int Screen::get_string( const std::string & prompt,
                      { key = -2; history.back() = name; } }
                  break;
       case KEY_F(1) : Help::help_menu( key ); break;
+      case KEY_F(9) : if( allow_copy && Block::valid() &&
+                          Block::begin().line == Block::end().line )
+                        {
+                        std::string tmp;
+                        unsigned int len = Block::buffer().to_string( Block::begin(), Block::end(), tmp );
+                        if( len ) { s.insert( scol, tmp ); scol += len; modified = true; }
+                        }
+                      break;
       case KEY_DC   : if( scol < s.size() )
                         { s.erase( scol, 1 ); modified = true; } break;
       case KEY_BACKSPACE: if( scol > prompt.size() )
