@@ -1,4 +1,4 @@
-/*  Moe - My Own Editor
+/*  GNU Moe - My Own Editor
     Copyright (C) 2005 Antonio Diaz Diaz.
 
     This program is free software; you can redistribute it and/or modify
@@ -78,6 +78,7 @@ public:
   void load_file() throw();
   void split_window() throw();
   void save_file() const throw();
+  void save_all_named() const throw();
   int close( bool abort, const bool quiet = false ) throw();
   int close_and_exit( const bool abort ) throw();
 
