@@ -1,4 +1,4 @@
-/*  Moe - My Own Editor
+/*  GNU Moe - My Own Editor
     Copyright (C) 2005 Antonio Diaz Diaz.
 
     This program is free software; you can redistribute it and/or modify
@@ -17,6 +17,7 @@
 */
 
 #include <algorithm>
+#include <cctype>
 #include <string>
 #include <vector>
 
@@ -132,7 +133,7 @@ void Window_vector::split_window() throw()
 
 void Window_vector::save_file() const throw()
   {
-  Buffer & buffer = data[_curwin].buffer();
+  const Buffer & buffer = data[_curwin].buffer();
 
   std::string name = buffer.name();
   if( File::get_filename( "Name of file to save (^C to abort): ", name ) <= 0 )
@@ -150,6 +151,15 @@ void Window_vector::save_file() const throw()
   }
 
 
+void Window_vector::save_all_named() const throw()
+  {
+  const bool done = bufhandle_vector.save_all_named();
+  show_status_lines();
+  if( done ) Screen::show_message( "All named buffers saved" );
+  else Screen::show_message( "Not all named buffers saved" );
+  }
+
+
 // Returns number of windows, 0 if none, -1 if aborted.
 //
 int Window_vector::close( bool abort, const bool quiet ) throw()
@@ -163,13 +173,11 @@ int Window_vector::close( bool abort, const bool quiet ) throw()
   if( !abort || !quiet )
     {
     if( abort && modified && last_handle )
-      while( true )
-        {
-        int key = Screen::show_message( "Lose changes to this file ? (y/n/^C) ", true, true );
-        if( key == 3 ) return -1;
-        if( key == 'n' || key == 'N' ) { abort = false; break; }
-        if( key == 'y' || key == 'Y' ) break;
-        }
+      {
+      int key = Screen::show_message( "Lose changes to this file ? (y/n/^C) ", true, true );
+      if( key == 'n' || key == 'N' ) abort = false;
+      else if( key != 'y' && key != 'Y' ) return -1;
+      }
     if( !abort && modified )
       {
       std::string name = bh.buffer().name();
@@ -494,7 +502,7 @@ void Window_vector::reformat() throw()
     for( Point p = bot; p < eop; )
       {
       unsigned char ch = buffer.pgetc( p );
-      if( !isspace( ch ) )
+      if( !std::isspace( ch ) )
         { tmp.pputc( dummy, ch ); dummy = tmp.eof(); space = false; }
       else if( !space ) { tmp.pputc( dummy, ' ' ); space = true; }
       }
@@ -556,7 +564,7 @@ void Window_vector::search( const bool again ) throw()
     {
     search_string.clear();
     search_history.push_back( std::string() );
-    if( Screen::get_string( "Find (^C to abort): ", search_history ) <= 0 ) return;
+    if( Screen::get_string( "Find (^C to abort): ", search_history, true ) <= 0 ) return;
     search_string = search_history.back(); ISO_8859::deescapize( search_string );
     std::string prompt;
     if( RC::options().ignore_case )
@@ -586,7 +594,7 @@ void Window_vector::search( const bool again ) throw()
       {
       replace_string.clear();
       replace_history.push_back( std::string() );
-      const int len = Screen::get_string( "Replace with (^C to abort): ", replace_history );
+      const int len = Screen::get_string( "Replace with (^C to abort): ", replace_history, true );
       if( len < 0 ) { replace = false; return; }
       if( len > 0 )
         { replace_string = replace_history.back();
